@@ -1,8 +1,7 @@
-# import os
-# os.system("conda activate torch_base")
-
 from . import custom_models
 from . import CustomModels
 from . import Utilities
+from . import DataVisualizations
+from . import TrainingUtilities
 
-version='0.3.15'
+version='0.4.1'
