@@ -8,7 +8,8 @@ import torch
 import os
 import seaborn as sns
 import random
-import json
+import yaml
+import sys
 
 from datetime import datetime
 from PIL import Image
@@ -17,9 +18,9 @@ from torch import nn, optim
 from torchvision import datasets, transforms, models
 from torch.utils.data import DataLoader, Dataset
 from tqdm import tqdm
-# from pretrainedmodels.models.xception import Xception
-# from pretrainedmodels.models.mobilenetv2 import MobileNetV2
-from pytorch_vision_utils.Utilities import DataVisualizationUtilities, TrainingUtilities
+
+from pytorch_vision_utils.DataVisualizations import DataVisualizationUtilities
+from pytorch_vision_utils.TrainingUtilities import TrainingUtilities
 
 
 
@@ -34,35 +35,22 @@ MODEL_NAME = args["model_name"] # "xception"
 PARAMS = args["parameters_path"]
 DEBUG = "True" == args["debug"]
 
-
-# DIRECTORY NAMES
-with open(PARAMS, "r") as f:
-    print("Loading parameters...\n")
-    params = dict(json.load(f))
-    
-    DATA_DIR = params["DATA_DIR"]
-    TEST_DIR = params["TEST_DIR"]
-    MODEL_DIR = params["MODEL_DIR"]
-    MEDIA_DIR = params["MEDIA_DIR"]
-    INC_DIR = params["INC_DIR"]
-    
-    print("Loading parameters complete!")
-    print(MODEL_DIR)
-    print(TEST_DIR)
-    print(MEDIA_DIR)
-    print(DATA_DIR)
-
 device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
 print("Using: ", device)
 
-train_utils = TrainingUtilities(data_dir=DATA_DIR, model_dir=MODEL_DIR, device=device, parameters_path=PARAMS, model_name=MODEL_NAME)
+train_utils = TrainingUtilities(device=device, parameters_path=PARAMS, model_name=MODEL_NAME)
 dataviz_utils = DataVisualizationUtilities()
 
 
 
 ##################### T R A I N I N G #####################
 
+def main():
+    loss, acc = train_utils.train(model_name=MODEL_NAME, show_graphs=False, dry_run=False, debug=DEBUG)
+    if not loss:
+        sys.exit(-1)
+
 if __name__ == "__main__":
-    loss, acc = train_utils.train(model_name=MODEL_NAME, model_path=MODEL_DIR, inc_path=INC_DIR, media_dir=MEDIA_DIR, show_graphs=False, dry_run=False, debug=DEBUG)
+    main()
     
 
